@@ -1,8 +1,10 @@
 import logging
 import os
 import sys
+from enum import IntEnum
 
 from tryceratops.analyzers import Runner
+from tryceratops.files.discovery import FileDiscovery
 from tryceratops.settings import ERROR_LOG_FILENAME
 from tryceratops.violations import Violation
 
@@ -10,10 +12,18 @@ from tryceratops.violations import Violation
 class COLORS:
     DESCR = "\033[91m"
     CODE = "\033[93m"
+    ERROR = "\033[91m"
 
     ENDC = "\033[0m"
 
 
+class ExitCodes(IntEnum):
+    SUCCESS = 0
+    LINT_BROKEN = 1
+    UNPROCESSED_FILE = 2
+    RUNTIME_ISSUES = 100
+
+
 def wrap_color(msg: str, color: str):
     return f"{color}{msg}{COLORS.ENDC}"
 
@@ -27,8 +37,9 @@ def present_violation(violation: Violation):
 
 
 class CliInterface:
-    def __init__(self, runner: Runner):
+    def __init__(self, runner: Runner, discovery: FileDiscovery):
         self.runner = runner
+        self.discovery = discovery
 
     def _present_violations(self):
         for violation in self.runner.violations:
@@ -43,6 +54,11 @@ class CliInterface:
         else:
             print("Nothing to check!")
 
+        if self.discovery.had_issues:
+            print(
+                wrap_color(f"Failed to process {len(self.discovery.failures)} files", COLORS.ERROR)
+            )
+
         if self.runner.excluded_files:
             print(f"Skipped {self.runner.excluded_files} files")
 
@@ -53,12 +69,14 @@ class CliInterface:
             )
 
     def _exit(self):
-        exit_code = 0
+        exit_code = ExitCodes.SUCCESS
 
         if self.runner.had_issues:
-            exit_code = 2
+            exit_code = ExitCodes.RUNTIME_ISSUES
+        elif self.discovery.had_issues:
+            exit_code = ExitCodes.UNPROCESSED_FILE
         elif self.runner.any_violation:
-            exit_code = 1
+            exit_code = ExitCodes.LINT_BROKEN
 
         sys.exit(exit_code)
 
