@@ -7,7 +7,10 @@ LOGGING_CONFIG = {
         "default": {
             "format": "%(asctime)s:%(name)s:%(process)d:%(lineno)d " "%(levelname)s %(message)s",
             "datefmt": "%Y-%m-%d %H:%M:%S",
-        }
+        },
+        "simple": {
+            "format": "%(message)s",
+        },
     },
     "handlers": {
         "logfile": {
@@ -17,6 +20,20 @@ LOGGING_CONFIG = {
             "formatter": "default",
             "backupCount": 2,
         },
+        "verbose_output": {
+            "class": "logging.StreamHandler",
+            "level": "DEBUG",
+            "formatter": "simple",
+            "stream": "ext://sys.stdout",
+        },
+    },
+    "loggers": {
+        "tryceratops": {
+            "level": "INFO",
+            "handlers": [
+                "verbose_output",
+            ],
+        },
     },
     "root": {"level": "INFO", "handlers": ["logfile"]},
 }
